<?php

declare(strict_types=1);

namespace Drupal\media_contextual_crop_embed\Plugin\MediaContextualCropUseCase;

use Drupal\image\Plugin\Field\FieldType\ImageItem;
use Drupal\media_contextual_crop\MediaContextualCropUseCasePluginBase;

/**
 * Plugin implementation of the media_contextual_crop_use_case.
 *
 * @MediaContextualCropUseCase(
 *   id = "embed",
 *   label = @Translation("Embed"),
 *   default_folder = "multi_crop_embed"
 * )
 */
class Embed extends MediaContextualCropUseCasePluginBase {

  /**
   * {@inheritdoc}
   */
  public function isCompetent(ImageItem $item) {
    return (isset($item->media_contextual_crop_plugin_type) && isset($item->media_contextual_crop_embed_settings));
  }

  /**
   * {@inheritdoc}
   */
  public function getContextualUri(ImageItem $item, $old_uri, $image_style) {

    $crop_settings = $this->getCropSettings($item);

    if ($crop_settings != NULL) {

      $crop_settings['image_style'] = $image_style;
      $item_values = $item->getValue();
      $old_image = [
        '#uri' => $old_uri,
        '#width' => $item_values['width'],
        '#height' => $item_values['height'],
      ];

      // Prepare Crop & generate new image path.
      $new_uri = $this->mccService->prepareCropImage($old_image, $crop_settings);
      return $new_uri;
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getCropSettings(ImageItem $item) {
    if ($plugin_id = $item->media_contextual_crop_plugin_type) {

      if ($embed_data = $item->media_contextual_crop_embed_settings) {

        // Load contextual Crop plugins.
        /** @var \Drupal\media_contextual_crop\MediaContextualCropInterface $plugin */
        $plugin = $this->mccPluginManager->createInstance($plugin_id);

        // Get usable CROP settings.
        $media_contextual_crop_settings = $plugin->processEmbedData($embed_data, ['image_style' => $image_style]);

        return $media_contextual_crop_settings;
      }
    }

    return NULL;
  }

}
